####################################################################;
# TRADE APPLICATION:  INFLUENCE FUNCTIONS; 
####################################################################;

# Empirical application of the paper "Panel Quantile Effects Via Distribution Regression"
# Authors: V. Chernozhukov, I. Fernandez-Val, M. Weidner

# Source: Helpman, Melitz, Rubinstein: "Estimating Trade Flows: Trading Partners and Trading Volumes, 2008,
# QJE, 123(2), pp. 441-487;

# Data: Helpman and Melitz web site;

# Std errors assume correct specification;

# 100% increase in distance;

# Source directory in SCC "/project/ivangrp/PDR/";

# These influence functions are for the function-valued standard errors and multiplier bootstrapped critical values;

rm(list=ls());

library(parallel);
library(abind);

str.trim <- "_c95"; # "","_c99","_c95";

load(paste("EmpApp_Est",str.trim,".RData", sep=""));
source("PDR_Source.R");

####################
# Parallel Setting #
####################

# Calculate the namber of cores
n.cores <- as.numeric(Sys.getenv("NSLOTS"));
if(is.na(n.cores))n.cores<-1;


#######################
# Influence Functions #
#######################

phi.all.l <- mclapply(1:n.thres, phi.logit, mc.cores=ceiling(n.cores/5), model.spec=model.spec, data.local=trade.data, 
                    ys=ys, theta.ys=theta.ys, t.log2=t.log2, t.d=t.d);
phi.all <- do.call(abind, list(phi.all.l,along=3)); # n.obs*(n.K+n.I+n.J-1 + 4)*n.thres;
rm(phi.all.l);


#########################################
# Influence Function of Average Effects #
#########################################
phi.ae <- matrix(0,nrow=NROW(trade.data),ncol=length(c(t.log2,t.d)));

for(i in 1:length(c(t.log2,t.d))){
  t <- c(t.log2,t.d)[i];
  phi.ae.integrand <- apply(phi.all[,paste("F.",X.name[t],".1",sep=""),]-phi.all[,paste("F.",X.name[t],".0",sep=""),], 
                            1, approxfun, x=ys, rule=2:1);
  phi.ae[,i] <- sapply(phi.ae.integrand, 
                       function(myfunc){-integrate(myfunc,ys[1],ys[n.thres],subdivisions=2000,stop.on.error=F)$value});
  rm(phi.ae.integrand);
};



save.image(paste("EmpApp_Inf",str.trim,".RData", sep=""));
